@@ -41,6 +41,9 @@ FAILEDOPERATION_LICENSENOQUOTA = 'FailedOperation.LicenseNoQuota'
 # 签署审核未通过，请先完成审核。
 FAILEDOPERATION_NOSIGNREVIEWPASS = 'FailedOperation.NoSignReviewPass'
 
+# 此合同流程不支持审批
+FAILEDOPERATION_NOTAVAILABLESIGNREVIEW = 'FailedOperation.NotAvailableSignReview'
+
 # 未找到集团子企业相关用户信息，请检查用户相关参数
 FAILEDOPERATION_NOTFOUNDSHADOWUSER = 'FailedOperation.NotFoundShadowUser'
 
@@ -71,6 +74,12 @@ FAILEDOPERATION_REQUESTLIMITEXCEEDED = 'FailedOperation.RequestLimitExceeded'
 # 模板无资源信息。
 FAILEDOPERATION_TEMPLATEHASNORESOURCE = 'FailedOperation.TemplateHasNoResource'
 
+# 无法撤销，用户已开通自动签。
+FAILEDOPERATION_USERAUTOSIGNENABLEALREADY = 'FailedOperation.UserAutoSignEnableAlready'
+
+# 无法撤销，用户未生成开通链接。
+FAILEDOPERATION_USERAUTOSIGNENABLEURLNOTEXIST = 'FailedOperation.UserAutoSignEnableUrlNotExist'
+
 # 用户信息不匹配，请检查后重试。
 FAILEDOPERATION_USERINFONOMATCH = 'FailedOperation.UserInfoNoMatch'
 
@@ -299,7 +308,7 @@ INVALIDPARAMETER_RESOURCETYPE = 'InvalidParameter.ResourceType'
 # 角色ID不正确
 INVALIDPARAMETER_ROLEID = 'InvalidParameter.RoleId'
 
-# 不合法的印章id，请检查印章id是够正确，并在修改后重试。
+# 不合法的印章id，请检查印章id是否正确，并在修改后重试。
 INVALIDPARAMETER_SEALID = 'InvalidParameter.SealId'
 
 # 参数包含有敏感词
